@@ -3,7 +3,10 @@
 """Univention Configuration Registry helper functions."""
 #  main configuration registry classes
 #
-# Copyright 2004-2021 Univention GmbH
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -38,7 +41,7 @@ import re
 import string  # pylint: disable-msg=W0402
 from pipes import quote as escape_value
 try:
-	from typing import Dict, IO, List, Text  # noqa F401
+	from typing import Dict, IO, List, Text  # noqa: F401
 except ImportError:  # pragma: no cover
 	pass
 
